PySINDy Examples
================

This directory showcases the following examples of PySINDy in action.

`Feature overview <https://github.com/dynamicslab/pysindy/blob/master/examples/1_feature_overview.ipynb>`_
----------------
This notebook gives an almost exhaustive overview of the different features available in PySINDy. It's a good reference for how to set various options and work with different types of datasets.

`Introduction to SINDy <https://github.com/dynamicslab/pysindy/blob/master/examples/2_introduction_to_sindy.ipynb>`_
---------------------
We recommend that people new to SINDy start here. We give a gentle introduction to the SINDy method and how different steps in the algorithm are represented in PySINDy. We also show how to use PySINDy to learn a model for a simple linear differential equation.

`Original paper <https://github.com/dynamicslab/pysindy/blob/master/examples/3_original_paper.ipynb>`_
--------------
This notebook uses PySINDy to reproduce the examples in the `original SINDy paper <https://www.pnas.org/content/pnas/113/15/3932.full.pdf>`_. Namely, it applies PySINDy to the following problems:

* Linear 2D ODE
* Cubic 2D ODE
* Linear 3D ODE
* Lorenz system
* Fluid wake behind a cylinder
* Logistic map
* Hopf system

`Scikit-learn compatibility <https://github.com/dynamicslab/pysindy/blob/master/examples/4_scikit_learn_compatibility.ipynb>`_
--------------------------
Shows how PySINDy interfaces with various Scikit-learn objects.

* Cross-validation
* Sparse regressors

`Differentiation <https://github.com/dynamicslab/pysindy/blob/master/examples/5_differentiation.ipynb>`_
---------------
Expore the differentiation methods available in PySINDY on pure differentiation problems and as components in the SINDy algorithm.
